==> incolume_py_changelog-0.3.0a9-py3-none-any.whl: README.md <==
# Python Incolume Utils

--------

_Projeto desenvolvido e administrado incolume.com.br_

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/incolumepy.makefilelicense)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Tests CI/CD](https://github.com/development-incolume/incolume.py.changelog/actions/workflows/tests-gwa-ci-cd.yml/badge.svg)](https://github.com/development-incolume/incolume.py.changelog/actions/workflows/tests-gwa-ci-cd.yml)
![PyPI - Status](https://img.shields.io/pypi/status/incolumepy.makefilelicense)
[![GitHub Actions (Tests)](https://github.com/development-incolume/incolume.py.changelog/workflows/Tests/badge.svg)](https://github.com/development-incolume/incolume.py.changelog/)
[![codecov](https://codecov.io/gh/incolumepy/incolumepy.makefilelicense/branch/main/graph/badge.svg?token=QFULL7R8HX)](https://codecov.io/gh/incolumepy/incolumepy.makefilelicense)
![PyPI](https://img.shields.io/pypi/v/incolumepy.makefilelicense)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/incolumepy/incolumepy.makefilelicense?logo=tag)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/incolumepy.makefilelicense)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/incolumepy.makefilelicense)
![PyPI - License](https://img.shields.io/pypi/l/incolumepy.makefilelicense)
!["Code style: blue"](https://img.shields.io/badge/code%20style-blue-black)
!["Code style: ruff"](https://img.shields.io/badge/code%20style-ruff-black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=4444444)](https://pycqa.github.io/isort/)
[![Docstring style: pydocstyle](https://img.shields.io/badge/%20Docstring%20Style-PyDocStyle-%231674b1?style=flat&labelColor=444444)](http://www.pydocstyle.org/en/stable/)
[![Linter: mypy](https://img.shields.io/badge/%20Linter-Mypy-%231674b1?style=flat&labelColor=4444444)](https://mypy.readthedocs.io/en/stable/)
[![Linter: pylint](https://img.shields.io/badge/%20Linter-pylint-%231674b1?style=flat&labelColor=4444444)](https://pylint.pycqa.org/en/latest/)
[![Linter: flake8](https://img.shields.io/badge/%20Linter-flake8-%231674b1?style=flat&labelColor=4444444)](https://flake8.pycqa.org/en/latest/)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/incolumepy/incolumepy.makefilelicense)
![GitHub repo size](https://img.shields.io/github/repo-size/incolumepy/incolumepy.makefilelicense)
![GitHub issues](https://img.shields.io/github/issues/incolumepy/incolumepy.makefilelicense)
![GitHub closed issues](https://img.shields.io/github/issues-closed/incolumepy/incolumepy.makefilelicense)
![GitHub closed issues by-label](https://img.shields.io/github/issues-closed/incolumepy/incolumepy.makefilelicense/enhancement)
![GitHub issues by-label](https://img.shields.io/github/issues/incolumepy/incolume.py.changelog/bug)
![GitHub issues by-label](https://img.shields.io/github/issues/incolumepy/incolume.py.changelog/enhancement)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog)](https://pepy.tech/project/incolume-py-changelog)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog/month)](https://pepy.tech/project/incolume-py-changelog)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog/week)](https://pepy.tech/project/incolume-py-changelog)
---

Este gera o Changelog a partir dos registros encontrados em `git tag -n`.

## Instalar o pacote

### Instalação com pip
```shell
pip install incolume.py.changelog
```
### Instalação com pipenv
```shell
pipenv install incolume.py.changelog
```

### Instalação com poetry
```shell
poetry add incolume.py.changelog
```

```shell
poetry add git+https://gitlab.com/development-incolume/incolumepy.utils.git#main
```

## Atualizar o pacote
### Atualização com pip
```shell
pip install -U incolume.py.changelog
```
### Atualização com pipenv
```shell
pipenv update incolume.py.changelog
```
### Atualização com poetry
```shell
poetry update incolume.py.changelog
```

```shell
poetry update git+https://gitlab.com/development-incolume/incolumepy.utils.git#main
```

## Gerar pacote a partir dos fontes para instalação

```shell
poetry build
```

## Documentação detalhada
Exemplos da API disponíveis em [docs/api]('docs/api/index.md')

==> incolume_py_changelog-0.6.0-py3-none-any.whl: README.md <==
# Python Incolume Utils

--------

_Projeto desenvolvido e administrado incolume.com.br_

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/incolumepy.makefilelicense)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Tests CI/CD](https://github.com/development-incolume/incolume.py.changelog/actions/workflows/tests-gwa-ci-cd.yml/badge.svg)](https://github.com/development-incolume/incolume.py.changelog/actions/workflows/tests-gwa-ci-cd.yml)
![PyPI - Status](https://img.shields.io/pypi/status/incolume.py.changelog)
[![GitHub Actions (Tests)](https://github.com/development-incolume/incolume.py.changelog/workflows/Tests/badge.svg)](https://github.com/development-incolume/incolume.py.changelog/)
[![codecov](https://codecov.io/gh/incolumepy/incolumepy.makefilelicense/branch/main/graph/badge.svg?token=QFULL7R8HX)](https://codecov.io/gh/incolumepy/incolumepy.makefilelicense)
![PyPI](https://img.shields.io/pypi/v/incolume.py.changelog)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/incolumepy/incolumepy.makefilelicense?logo=tag)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/incolume.py.changelog)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/incolumepy.makefilelicense)
![PyPI - License](https://img.shields.io/pypi/l/incolume.py.changelog)
!["Code style: blue"](https://img.shields.io/badge/code%20style-blue-black)
!["Code style: ruff"](https://img.shields.io/badge/code%20style-ruff-black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=4444444)](https://pycqa.github.io/isort/)
[![Docstring style: pydocstyle](https://img.shields.io/badge/%20Docstring%20Style-PyDocStyle-%231674b1?style=flat&labelColor=444444)](http://www.pydocstyle.org/en/stable/)
[![Linter: mypy](https://img.shields.io/badge/%20Linter-Mypy-%231674b1?style=flat&labelColor=4444444)](https://mypy.readthedocs.io/en/stable/)
[![Linter: pylint](https://img.shields.io/badge/%20Linter-pylint-%231674b1?style=flat&labelColor=4444444)](https://pylint.pycqa.org/en/latest/)
[![Linter: flake8](https://img.shields.io/badge/%20Linter-flake8-%231674b1?style=flat&labelColor=4444444)](https://flake8.pycqa.org/en/latest/)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/incolumepy/incolumepy.makefilelicense)
![GitHub repo size](https://img.shields.io/github/repo-size/incolumepy/incolumepy.makefilelicense)
![GitHub issues](https://img.shields.io/github/issues/incolumepy/incolumepy.makefilelicense)
![GitHub closed issues](https://img.shields.io/github/issues-closed/incolumepy/incolumepy.makefilelicense)
![GitHub closed issues by-label](https://img.shields.io/github/issues-closed/incolumepy/incolumepy.makefilelicense/enhancement)
![GitHub issues by-label](https://img.shields.io/github/issues/incolumepy/incolume.py.changelog/bug)
![GitHub issues by-label](https://img.shields.io/github/issues/incolumepy/incolume.py.changelog/enhancement)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog)](https://pepy.tech/project/incolume-py-changelog)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog/month)](https://pepy.tech/project/incolume-py-changelog)
[![Downloads](https://pepy.tech/badge/incolume-py-changelog/week)](https://pepy.tech/project/incolume-py-changelog)
---

Este gera o Changelog a partir dos registros encontrados em `git tag -n`.

## Instalar o pacote

### Instalação com pip
```shell
pip install incolume.py.changelog
```
### Instalação com pipenv
```shell
pipenv install incolume.py.changelog
```

### Instalação com poetry
```shell
poetry add incolume.py.changelog
```

```shell
poetry add git+https://gitlab.com/development-incolume/incolumepy.utils.git#main
```

## Atualizar o pacote
### Atualização com pip
```shell
pip install -U incolume.py.changelog
```
### Atualização com pipenv
```shell
pipenv update incolume.py.changelog
```
### Atualização com poetry
```shell
poetry update incolume.py.changelog
```

```shell
poetry update git+https://gitlab.com/development-incolume/incolumepy.utils.git#main
```

## Gerar pacote a partir dos fontes para instalação

```shell
poetry build
```

## Documentação detalhada
Exemplos da API disponíveis em [docs/api]('docs/api/index.md')
